@@ -35,7 +35,9 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
 #include "xf86Resources.h"
+#endif
 #include "xf86cmap.h"
 #include "compiler.h"
 #include "mipointer.h"
@@ -419,8 +421,10 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	return FALSE;
 
     pEnt = xf86GetEntityInfo(pScrni->entityList[0]);
+#ifndef XSERVER_LIBPCIACCESS
     if (pEnt->resources)
 	return FALSE;
+#endif
 
     pGeode = pScrni->driverPrivate = xnfcalloc(sizeof(GeodeRec), 1);
 
@@ -507,7 +511,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
     pGeode->tryCompression = TRUE;
 
     pGeode->NoAccel = FALSE;
-    pGeode->useEXA = TRUE;
+    pGeode->useEXA = FALSE;
 
     pGeode->Panel = (pGeode->Output & OUTPUT_PANEL) ? TRUE : FALSE;
 
@@ -578,7 +582,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	    pGeode->useEXA = FALSE;
 	else if (xf86NameCmp(s, "EXA"))
 	    xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-		"Unknown accleration method %s.  Defaulting to EXA.\n", s);
+		"Unknown accleration method %s.  Defaulting to XAA.\n", s);
     }
 
     xf86DrvMsg(pScrni->scrnIndex, X_INFO,
@@ -704,12 +708,13 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	}
     }
 
+#ifndef XSERVER_LIBPCIACCESS
     if (xf86RegisterResources(pGeode->pEnt->index, NULL, ResExclusive)) {
 	xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
 	    "Couldn't register the resources.\n");
 	return FALSE;
     }
-
+#endif
     return TRUE;
 }
 
@@ -1407,7 +1412,7 @@ GXValidMode(int scrnIndex, DisplayModePtr pMode, Bool Verbose, int flags)
 {
     ScrnInfoPtr pScrni = xf86Screens[scrnIndex];
     GeodeRec *pGeode = GEODEPTR(pScrni);
-    int p, ret;
+    int p;
     int custom = 0;
 
     if (pGeode->Panel)
@@ -1417,23 +1422,24 @@ GXValidMode(int scrnIndex, DisplayModePtr pMode, Bool Verbose, int flags)
 
     /* Use the durango lookup for !custom modes */
 
-    if (!custom) {
-	if (pGeode->Panel) {
-	    if (pMode->CrtcHDisplay > pGeode->PanelX ||
-		pMode->CrtcVDisplay > pGeode->PanelY ||
-		gfx_is_panel_mode_supported(pGeode->PanelX, pGeode->PanelY,
-		    pMode->CrtcHDisplay, pMode->CrtcVDisplay,
-		    pScrni->bitsPerPixel) < 0) {
+    if (!custom && pGeode->Panel) {
+        if (pMode->CrtcHDisplay > pGeode->PanelX ||
+            pMode->CrtcVDisplay > pGeode->PanelY ||
+            gfx_is_panel_mode_supported(pGeode->PanelX,
+                                        pGeode->PanelY,
+                                        pMode->CrtcHDisplay,
+                                        pMode->CrtcVDisplay,
+                                        pScrni->bitsPerPixel) < 0) {
 
-		return MODE_BAD;
-	    }
-	}
+            return MODE_BAD;
+        }
+    }
 
-	ret = gfx_is_display_mode_supported(pMode->CrtcHDisplay,
-	    pMode->CrtcVDisplay,
-	    pScrni->bitsPerPixel, GeodeGetRefreshRate(pMode));
-	if (ret < 0)
-	    return MODE_BAD;
+    if (gfx_is_display_mode_supported(pMode->CrtcHDisplay,
+                                      pMode->CrtcVDisplay,
+                                      pScrni->bitsPerPixel,
+                                      GeodeGetRefreshRate(pMode)) < 0) {
+        return MODE_BAD;
     }
 
     if (pMode->Flags & V_INTERLACE)
